/* 
 
Copyright 2006 Rene Grothmann, modified by Eric Hakenholz

This file is part of C.a.R. software.

    C.a.R. is a free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, version 3 of the License.

    C.a.R. is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 */
 
 
 package rene.zirkel.structures;

// file: CoordinatesXY.java

public class CoordinatesXY implements Comparable<CoordinatesXY>{
	public double X=Double.NaN, Y=Double.NaN;

	public CoordinatesXY(final double x, final double y) {
		X = x;
		Y = y;
	}
        public CoordinatesXY(){
            
        }

    public int compareTo(CoordinatesXY o) {
        if (Double.isNaN(X)) return -1;
        if (Double.isNaN(o.X)) return 1;
        if (o.X==X) return 0;
        if (X<o.X) return -1;
        return 1;
    }
}
